@@ -71,15 +71,63 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 操作频繁，请稍后重试。
 INVALIDPARAMETER_ACTIONINPROGRESS = 'InvalidParameter.ActionInProgress'
 
+# HTTPS证书链错误。
+INVALIDPARAMETER_CERTCHAINERROR = 'InvalidParameter.CertChainError'
+
+# 证书错误。
+INVALIDPARAMETER_CERTCHECKERROR = 'InvalidParameter.CertCheckError'
+
+# 证书错误。
+INVALIDPARAMETER_CERTCOMPLETEERROR = 'InvalidParameter.CertCompleteError'
+
+# 证书错误。
+INVALIDPARAMETER_CERTFORMATERROR = 'InvalidParameter.CertFormatError'
+
+# HTTPS证书已过期。
+INVALIDPARAMETER_CERTISEXPIRED = 'InvalidParameter.CertIsExpired'
+
+# 证书错误。
+INVALIDPARAMETER_CERTNOCN = 'InvalidParameter.CertNoCn'
+
+# 无效的HTTPS证书。
+INVALIDPARAMETER_CERTNOINFO = 'InvalidParameter.CertNoInfo'
+
+# HTTPS证书和域名不匹配。
+INVALIDPARAMETER_CERTNOTMATCHDOMAIN = 'InvalidParameter.CertNotMatchDomain'
+
+# HTTPS证书和密钥不匹配。
+INVALIDPARAMETER_CERTNOTMATCHKEY = 'InvalidParameter.CertNotMatchKey'
+
+# 证书错误。
+INVALIDPARAMETER_CERTNOTPEM = 'InvalidParameter.CertNotPem'
+
+# 内部错误。
+INVALIDPARAMETER_CERTSYSTEMERROR = 'InvalidParameter.CertSystemError'
+
+# HTTPS证书即将过期。
+INVALIDPARAMETER_CERTTOEXPIRE = 'InvalidParameter.CertToExpire'
+
+# 证书错误。
+INVALIDPARAMETER_CERTTOOSHORTKEYSIZE = 'InvalidParameter.CertTooShortKeySize'
+
+# 证书错误。
+INVALIDPARAMETER_CERTUNSUPPORTEDTYPE = 'InvalidParameter.CertUnsupportedType'
+
 # 域名不存在或不属于该账号。
 INVALIDPARAMETER_DOMAINNOTFOUND = 'InvalidParameter.DomainNotFound'
 
 # 当前域名已开启流量调度功能。
 INVALIDPARAMETER_DOMAINONTRAFFICSCHEDULING = 'InvalidParameter.DomainOnTrafficScheduling'
 
+# 非法操作。
+INVALIDPARAMETER_ERRINVALIDACTION = 'InvalidParameter.ErrInvalidAction'
+
 # 非法操作-非法参数。
 INVALIDPARAMETER_ERRINVALIDACTIONPARAM = 'InvalidParameter.ErrInvalidActionParam'
 
+# 非法操作-非法参数-参数名重复。
+INVALIDPARAMETER_ERRINVALIDACTIONPARAMDUPLICATENAME = 'InvalidParameter.ErrInvalidActionParamDuplicateName'
+
 # 非法操作-非法参数-参数值数量超出限制。
 INVALIDPARAMETER_ERRINVALIDACTIONPARAMTOOMANYVALUES = 'InvalidParameter.ErrInvalidActionParamTooManyValues'
 
@@ -89,6 +137,9 @@ INVALIDPARAMETER_ERRINVALIDCONDITIONNAMETARGETNOTSUPPORTNAME = 'InvalidParameter
 # 非法条件-非法参数值-无效的参数值。
 INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEBADVALUE = 'InvalidParameter.ErrInvalidConditionValueBadValue'
 
+# 非法条件-非法参数值-无效的参数值-文件名不应包含文件后缀。
+INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEBADVALUECONTAINFILENAMEEXTENSION = 'InvalidParameter.ErrInvalidConditionValueBadValueContainFileNameExtension'
+
 # 非法条件-非法参数值-参数值长度超出限制。
 INVALIDPARAMETER_ERRINVALIDCONDITIONVALUETOOLONGVALUE = 'InvalidParameter.ErrInvalidConditionValueTooLongValue'
 
@@ -98,6 +149,9 @@ INVALIDPARAMETER_HOSTNOTFOUND = 'InvalidParameter.HostNotFound'
 # 无效的token鉴权参数。
 INVALIDPARAMETER_INVALIDAUTHENTICATIONTYPESIGNPARAM = 'InvalidParameter.InvalidAuthenticationTypeSignParam'
 
+# 无效的缓存键。
+INVALIDPARAMETER_INVALIDCACHEKEY = 'InvalidParameter.InvalidCacheKey'
+
 # 无效的查询字符串。
 INVALIDPARAMETER_INVALIDCACHEKEYQUERYSTRINGVALUE = 'InvalidParameter.InvalidCacheKeyQueryStringValue'
 
@@ -116,6 +170,9 @@ INVALIDPARAMETER_INVALIDDYNAMICROUTINE = 'InvalidParameter.InvalidDynamicRoutine
 # 无效的自定义错误页面。
 INVALIDPARAMETER_INVALIDERRORPAGEREDIRECTURL = 'InvalidParameter.InvalidErrorPageRedirectUrl'
 
+# 无效的HTTPS HSTS。
+INVALIDPARAMETER_INVALIDHTTPSHSTSMAXAGE = 'InvalidParameter.InvalidHttpsHstsMaxAge'
+
 # 无效的HTTPS TLS版本。
 INVALIDPARAMETER_INVALIDHTTPSTLSVERSION = 'InvalidParameter.InvalidHttpsTlsVersion'
 
@@ -140,6 +197,9 @@ INVALIDPARAMETER_INVALIDREQUESTHEADERNAME = 'InvalidParameter.InvalidRequestHead
 # 无套餐包。
 INVALIDPARAMETER_INVALIDRESOURCEIDBILLING = 'InvalidParameter.InvalidResourceIdBilling'
 
+# 无效的响应头header。
+INVALIDPARAMETER_INVALIDRESPONSEHEADERNAME = 'InvalidParameter.InvalidResponseHeaderName'
+
 # 无效的规则引擎配置。
 INVALIDPARAMETER_INVALIDRULEENGINE = 'InvalidParameter.InvalidRuleEngine'
 
@@ -158,6 +218,9 @@ INVALIDPARAMETER_INVALIDRULEENGINETARGETSEXTENSION = 'InvalidParameter.InvalidRu
 # 无效的规则引擎URL条件。
 INVALIDPARAMETER_INVALIDRULEENGINETARGETSURL = 'InvalidParameter.InvalidRuleEngineTargetsUrl'
 
+# 无效的回源Host。
+INVALIDPARAMETER_INVALIDSERVERNAME = 'InvalidParameter.InvalidServerName'
+
 # URL重写的目标HOST无效。
 INVALIDPARAMETER_INVALIDURLREDIRECTHOST = 'InvalidParameter.InvalidUrlRedirectHost'
 
@@ -191,6 +254,9 @@ INVALIDPARAMETER_UPLOADURL = 'InvalidParameter.UploadUrl'
 # 站点不存在。
 INVALIDPARAMETER_ZONENOTFOUND = 'InvalidParameter.ZoneNotFound'
 
+# 参数取值错误。
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
 # 与已经添加的记录冲突。
 INVALIDPARAMETERVALUE_CONFLICTRECORD = 'InvalidParameterValue.ConflictRecord'
 
@@ -263,6 +329,9 @@ RESOURCEINUSE_CNAME = 'ResourceInUse.Cname'
 # Dns资源被占用。
 RESOURCEINUSE_DNS = 'ResourceInUse.Dns'
 
+# 已存在相同的别称域名。
+RESOURCEINUSE_DUPLICATENAME = 'ResourceInUse.DuplicateName'
+
 # 资源被本账号的子域名占用。
 RESOURCEINUSE_HOST = 'ResourceInUse.Host'
 
@@ -287,6 +356,9 @@ RESOURCEINUSE_OTHERSNS = 'ResourceInUse.OthersNS'
 # 资源被本账号和其他账号同时Cname接入占用。
 RESOURCEINUSE_SELFANDOTHERSCNAME = 'ResourceInUse.SelfAndOthersCname'
 
+# 别称域名已站点接入。
+RESOURCEINUSE_ZONE = 'ResourceInUse.Zone'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
